Module: Heart
- Defined in:
- lib/frame.rb
Overview
Heat module
Class Method Summary collapse
- .appmaker ⇒ Object
- .appmakerbr ⇒ Object
- .cooker ⇒ Object
- .creater ⇒ Object
- .databases ⇒ Object
- .default ⇒ Object
- .documents ⇒ Object
- .downloader ⇒ Object
- .installer ⇒ Object
- .nyasocom2_downloader ⇒ Object
- .nyasocom3_downloader ⇒ Object
- .nyasocom_app_downloader ⇒ Object
- .version ⇒ Object
Class Method Details
.appmaker ⇒ Object
105 106 107 108 109 110 111 112 113 114 |
# File 'lib/frame.rb', line 105 def appmaker require 'install' begin InstallerRunner.appmakers rescue LoadError => e puts e.backtrace ensure GC.compact end end |
.appmakerbr ⇒ Object
116 117 118 119 120 121 122 123 124 125 |
# File 'lib/frame.rb', line 116 def appmakerbr require 'install' begin InstallerRunner.app_maker_branches rescue LoadError => e puts e.backtrace ensure GC.compact end end |
.cooker ⇒ Object
39 40 41 42 43 44 45 46 47 48 |
# File 'lib/frame.rb', line 39 def cooker require 'install' begin InstallerRunner.cook rescue LoadError => e puts e.backtrace ensure GC.compact end end |
.creater ⇒ Object
28 29 30 31 32 33 34 35 36 37 |
# File 'lib/frame.rb', line 28 def creater require 'install' begin InstallerRunner.create rescue LoadError => e puts e.backtrace ensure GC.compact end end |
.databases ⇒ Object
94 95 96 97 98 99 100 101 102 103 |
# File 'lib/frame.rb', line 94 def databases require 'install' begin InstallerRunner.database rescue LoadError => e puts e.backtrace ensure GC.compact end end |
.default ⇒ Object
129 130 131 132 |
# File 'lib/frame.rb', line 129 def default str = 'nyasocom_frame is a framework for generating web applications. ' puts str end |
.documents ⇒ Object
134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/frame.rb', line 134 def documents puts text = <<-EOS # nyasocom framework information heat # version notation heat -v # nyasocom_oss project template generated heat ichi # nyasocom2 project template generated heat ni # nyasocom_sun_pg_win project template generated heat sun # nyasocom_sun_app project template generated heat app # template generation for nyasocom_oss heat new [Folder_Name] heat new example # template generation for nyasocom2 heat cook [Folder_Name] heat cook example # template generation for nyasocom_sun_pg_win heat create [Folder_Name] heat create example # nyasocom_pg project template generated heat db postgresql heat db --pg # github project templete generated heat make nyasocom takkii nyasocom_oss # github project templete generated + branch_name heat branch nyasocom takkii nyasocom_oss main # HELP heat -h EOS end |
.downloader ⇒ Object
50 51 52 53 54 55 56 57 58 59 |
# File 'lib/frame.rb', line 50 def downloader require 'install' begin InstallerRunner.download rescue LoadError => e puts e.backtrace ensure GC.compact end end |
.installer ⇒ Object
17 18 19 20 21 22 23 24 25 26 |
# File 'lib/frame.rb', line 17 def installer require 'install' begin InstallerRunner.install rescue LoadError => e puts e.backtrace ensure GC.compact end end |
.nyasocom2_downloader ⇒ Object
61 62 63 64 65 66 67 68 69 70 |
# File 'lib/frame.rb', line 61 def nyasocom2_downloader require 'install' begin InstallerRunner.nyasocom2_download rescue LoadError => e puts e.backtrace ensure GC.compact end end |
.nyasocom3_downloader ⇒ Object
72 73 74 75 76 77 78 79 80 81 |
# File 'lib/frame.rb', line 72 def nyasocom3_downloader require 'install' begin InstallerRunner.nyasocom3_download rescue LoadError => e puts e.backtrace ensure GC.compact end end |
.nyasocom_app_downloader ⇒ Object
83 84 85 86 87 88 89 90 91 92 |
# File 'lib/frame.rb', line 83 def nyasocom_app_downloader require 'install' begin InstallerRunner.nyasocom_app_download rescue LoadError => e puts e.backtrace ensure GC.compact end end |
.version ⇒ Object
12 13 14 15 |
# File 'lib/frame.rb', line 12 def version print Frame::FRAME_VERSION puts ' : [nyasocom_framework_version] ' end |